pub trait NonceWriter: NonceReader {
// Required methods
fn save_rsm_signer_nonce<'life0, 'life1, 'async_trait>(
&'life0 self,
record: &'life1 RsmSignerNonceRecord,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn reserve_next_rsm_signer_nonce<'life0, 'life1, 'async_trait>(
&'life0 self,
signer: &'life1 WalletAddress,
initial_nonce: u64,
) -> Pin<Box<dyn Future<Output = Result<u64>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn claim_rsm_signer_request<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
&'life0 self,
request_id: &'life1 str,
signer: &'life2 WalletAddress,
account: &'life3 WalletAddress,
action: &'life4 [u8],
initial_nonce: u64,
) -> Pin<Box<dyn Future<Output = Result<RsmSignerRequestClaim>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait;
fn complete_rsm_signer_request<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
request_id: &'life1 str,
directive: &'life2 [u8],
signature: &'life3 str,
) -> Pin<Box<dyn Future<Output = Result<RsmSignerRequestRecord>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait;
}Expand description
Nonce mutations for transaction sequencing.
Required Methods
Sourcefn save_rsm_signer_nonce<'life0, 'life1, 'async_trait>(
&'life0 self,
record: &'life1 RsmSignerNonceRecord,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn save_rsm_signer_nonce<'life0, 'life1, 'async_trait>(
&'life0 self,
record: &'life1 RsmSignerNonceRecord,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Save or update a signer nonce record.
fn reserve_next_rsm_signer_nonce<'life0, 'life1, 'async_trait>(
&'life0 self,
signer: &'life1 WalletAddress,
initial_nonce: u64,
) -> Pin<Box<dyn Future<Output = Result<u64>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Sourcefn claim_rsm_signer_request<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
&'life0 self,
request_id: &'life1 str,
signer: &'life2 WalletAddress,
account: &'life3 WalletAddress,
action: &'life4 [u8],
initial_nonce: u64,
) -> Pin<Box<dyn Future<Output = Result<RsmSignerRequestClaim>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
fn claim_rsm_signer_request<'life0, 'life1, 'life2, 'life3, 'life4, 'async_trait>(
&'life0 self,
request_id: &'life1 str,
signer: &'life2 WalletAddress,
account: &'life3 WalletAddress,
action: &'life4 [u8],
initial_nonce: u64,
) -> Pin<Box<dyn Future<Output = Result<RsmSignerRequestClaim>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
'life4: 'async_trait,
Claim a signer request slot, returning a nonce for signing.
Uses advisory locks and transactional nonce reservation to ensure exactly-once semantics per request_id.
Sourcefn complete_rsm_signer_request<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
request_id: &'life1 str,
directive: &'life2 [u8],
signature: &'life3 str,
) -> Pin<Box<dyn Future<Output = Result<RsmSignerRequestRecord>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn complete_rsm_signer_request<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
request_id: &'life1 str,
directive: &'life2 [u8],
signature: &'life3 str,
) -> Pin<Box<dyn Future<Output = Result<RsmSignerRequestRecord>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Mark a pending request as completed with the signed directive.